@@ -2,9 +2,7 @@ from typing import List
 from typing import Optional
 from typing import Union
 
-from superannotate_schemas.schemas.base import BaseModel
 from pydantic import Field
-from pydantic import StrictFloat
 from pydantic import StrictInt
 from pydantic import StrictStr
 from pydantic import ValidationError
@@ -14,19 +12,21 @@ from pydantic.error_wrappers import ErrorWrapper
 from superannotate_schemas.schemas.base import AxisPoint
 from superannotate_schemas.schemas.base import BaseAttribute
 from superannotate_schemas.schemas.base import BaseImageMetadata
+from superannotate_schemas.schemas.base import BaseInstanceTag
+from superannotate_schemas.schemas.base import BaseModel
 from superannotate_schemas.schemas.base import BaseVectorInstance
 from superannotate_schemas.schemas.base import BboxPoints
 from superannotate_schemas.schemas.base import Comment
 from superannotate_schemas.schemas.base import INVALID_DICT_MESSAGE
 from superannotate_schemas.schemas.base import NotEmptyStr
 from superannotate_schemas.schemas.base import StrictNumber
+from superannotate_schemas.schemas.base import StrictPointNumber
 from superannotate_schemas.schemas.base import Tag
-from superannotate_schemas.schemas.base import BaseInstanceTag
 from superannotate_schemas.schemas.enums import VectorAnnotationTypeEnum
 
 
 class InstanceTag(BaseInstanceTag):
-    class_name: NotEmptyStr
+    pass
 
 
 class Attribute(BaseAttribute):
@@ -47,11 +47,12 @@ class Point(VectorInstance, AxisPoint):
 
 
 class PolyLine(VectorInstance):
-    points: List[Union[StrictFloat, StrictInt]]
+    points: List[StrictPointNumber]
 
 
 class Polygon(VectorInstance):
-    points: conlist(Union[StrictFloat, StrictInt], min_items=3)
+    points: conlist(StrictPointNumber, min_items=3)
+    exclude: Optional[List[List[StrictPointNumber]]] = []
 
 
 class Bbox(VectorInstance):
